@@ -1,16 +1,18 @@
 # The contents of this file is free and unencumbered software released into the
 # public domain. For more information, please refer to <http://unlicense.org/>
 
-from anilistWrapPY.errors.types import AniListError
-from anilistWrapPY.errors.ex_class import AniListException
-from anilistWrapPY.Anime.types import AniListAnime
-from anilistWrapPY.Anime.graphql import anime_query
 import httpx
+import json
+
+from anilistWrapPY.Anime.graphql import anime_query
+from anilistWrapPY.Anime.types import AniListAnime, ani_list_anime_from_dict
+from anilistWrapPY.errors import AniListException, ani_list_error_from_dict
+
 
 def GetAnime(search: str, baseUrl: str) -> AniListAnime:
     variables = {"search": search}
     r = (httpx.post(baseUrl, json={"query": anime_query, "variables": variables})).json()
     try:
-        return AniListAnime(**r)
-    except AniListException:
-        return AniListError(**r)
\ No newline at end of file
+        return ani_list_anime_from_dict(r)
+    except json.JSONDecodeError:
+        raise AniListException("{]".format(ani_list_error_from_dict(r)))
